#ifndef Ch
#define Ch
//using cv;
class ColorHistogram {
	private:
	int histSize[3];
	float hranges[2];
	const float* ranges[3];
	int channels[3];
	public:
    // constructor
	ColorHistogram() {
	// Prepare arguments for a color histogram
		histSize[0]= histSize[1]= histSize[2]= 256;
		hranges[0]= 0.0; // BRG range
		hranges[1]= 255.0;
		ranges[0]= hranges; // all channels have the same range
		ranges[1]= hranges;
		ranges[2]= hranges;
		channels[0]= 0; // the three channels
		channels[1]= 1;
		channels[2]= 2;
	}
	cv::Mat colorReduce(const cv::Mat &image, int div=64) {
		int nl= image.rows; // number of lines
		int nc= image.cols ; // number of columns
		// is it a continous image?
		if (image.isContinuous()) {
		// then no padded pixels
			nc= nc*nl;
			nl= 1; // it is now a 1D array
		}
		cv::Mat result=image.clone();
		int n= static_cast<int>(log(static_cast<double>(div))/log(2.0));
		// mask used to round the pixel value
		uchar mask= 0xFF<<n; // e.g. for div=16, mask= 0xF0
		// for all pixels
		for (int j=0; j<nl; j++) {
			// pointer to first column of line j
			uchar* data= result.ptr<uchar>(j);
			for (int i=0; i<nc; i++) {
			// process each pixel ---------------------

				*data++= *data&mask + div/2;
				*data++= *data&mask + div/2;
				*data++= *data&mask + div/2;
				// end of pixel processing ----------------
			}
		}
		return result;
	}

	// get color histogram
	cv::MatND getHistogram(const cv::Mat &image) {
		cv::MatND hist;
		// Compute histogram
		cv::calcHist(&image,
		1, // histogram of 1 image only
		channels, // the channel used
		cv::Mat(), // no mask is used
		hist, // the resulting histogram
		3, // it is a 3D histogram
		histSize, // number of bins
		ranges // pixel value range
		);
		//cv:n
		//cv::normalizeHist(hist,500000);
		return hist;
	}
	cv::SparseMat getSparseHistogram(const cv::Mat &image) {
		cv::SparseMat hist(3,histSize,CV_32F);
		// Compute histogram
		cv::calcHist(&image,
		1, // histogram of 1 image only
		channels, // the channel used
		cv::Mat(), // no mask is used
		hist, // the resulting histogram
		3, // it is a 3D histogram
		histSize, // number of bins
		ranges // pixel value range
		);
		return hist;
	}

};
#endif